@@ -31,7 +31,7 @@ This private submodule is *not* intended for importation by downstream callers.
 #
 #Specifically, rather than accept "typing" nonsense verbatim, we could instead:
 #* Detect PEP 544-compatible protocol type hints *NOT* decorated by
-#  @typing.runtime_checkable. The existing is_type_or_types_isinstanceable() tester now
+#  @typing.runtime_checkable. The existing is_type_isinstanceable() tester now
 #  detects whether arbitrary classes are isinstanceable, so just call that.
 #* Emit a non-fatal warning advising the end user to resolve this on their end.
 #* Meanwhile, beartype can simply:
@@ -130,6 +130,7 @@ def coerce_func_hint_root(
         f'{repr(pith_name)} neither string nor "None".')
     assert bear_call.__class__ is BeartypeCall, (
         f'{repr(bear_call)} not @beartype call.')
+    # print(f'Coercing pith "{pith_name}" annotated by type hint {repr(hint)}...')
 
     # ..................{ FORWARD REFERENCE                  }..................
     # If this hint is stringified (e.g., as a PEP 484- or 563-compliant forward
@@ -192,11 +193,11 @@ def coerce_func_hint_root(
         # mypy idiosyncrasies merely to annotate an otherwise normal binary
         # dunder method is one expectation too far.
         #
-        # Ideally, official CPython developers would resolve this by declaring a
-        # new "types.NotImplementedType" type global resembling the existing
-        # "types.NoneType" type global. Since that has yet to happen, mypy has
-        # instead taken the surprisingly sensible course of silently ignoring
-        # this edge case by effectively performing the same type expansion as
+        # In theory, official CPython developers have already resolved this
+        # under Python >= 3.10 by defining the "types.NotImplementedType" type.
+        # In practice, that fails to assist older Python versions. Mypy has
+        # thus taken the surprisingly sensible course of silently ignoring this
+        # edge case by effectively performing the same type expansion as
         # performed here. *applause*
         return Union[hint, NotImplementedType]  # pyright: ignore[reportGeneralTypeIssues]
 
@@ -406,30 +407,15 @@ def coerce_hint_any(hint: object) -> Any:
     #   copy of this hint originally passed to a prior call of this function.
     if is_hint_uncached(hint):
         # print(f'Self-caching type hint {repr(hint)}...')
-        return _HINT_REPR_TO_SINGLETON.cache_or_get_cached_value(
+        return _hint_repr_to_hint.cache_or_get_cached_value(
             key=repr(hint), value=hint)
     # Else, this hint is (hopefully) self-caching.
 
     # Return this uncoerced hint as is.
     return hint
 
-# ....................{ CLEARERS                           }....................
-def clear_coerce_hint_caches() -> None:
-    '''
-    Clear (i.e., empty) *all* internal caches specifically leveraged by this
-    submodule, enabling callers to reset this submodule to its initial state.
-
-    Notably, this function clears:
-
-    * The **type hint cache** (i.e., private :data:`._HINT_REPR_TO_SINGLETON`
-      dictionary).
-    '''
-
-    # Clear our type hint cache.
-    _HINT_REPR_TO_SINGLETON.clear()
-
 # ....................{ PRIVATE ~ mappings                 }....................
-_HINT_REPR_TO_SINGLETON = CacheUnboundedStrong()
+_hint_repr_to_hint = CacheUnboundedStrong()
 '''
 **Type hint cache** (i.e., thread-safe cache mapping from the machine-readable
 representations of all non-self-cached type hints to cached singleton instances
