@@ -12,12 +12,12 @@ This private submodule is *not* intended for importation by downstream callers.
 '''
 
 # ....................{ TODO                               }....................
-#FIXME: Generalizing the "random_int" concept (i.e., the optional "random_int"
-#parameter accepted by the get_func_pith_violation() function) that enables
-#O(1) rather than O(n) exception handling to containers that do *NOT* provide
-#efficient random access like mappings and sets will be highly non-trivial.
-#While there exist a number of alternative means of implementing that
-#generalization, the most reasonable *BY FAR* is probably to:
+#FIXME: [ACCESS] Generalizing the "random_int" concept (i.e., the optional
+#"random_int" parameter accepted by the get_func_pith_violation() function) that
+#enables O(1) exception handling to containers that do *NOT* provide efficient
+#random access like mappings and sets will be highly non-trivial. While there
+#exist a number of alternative means of implementing that generalization, the
+#most reasonable *BY FAR* is probably to:
 #
 #* Embed additional assignment expressions in the type-checking tests generated
 #  by the make_func_pith_code() function that uniquely store the value of
@@ -64,15 +64,55 @@ This private submodule is *not* intended for importation by downstream callers.
 #  must be taken here to ensure that this exception handling algorithm visits
 #  containers in the exact same order as visited by our testing algorithm.
 
+#FIXME: [COLOR] The call to the strip_text_ansi() function below is inefficient
+#and thus non-ideal. Since efficiency isn't a pressing concern in an exception
+#raiser, this is more a matter of design purity than anything. Still, it would
+#be preferable to avoid embedding ANSI escape sequences when the user requests
+#that rather than forcibly stripping those sequences out after the fact via an
+#inefficient regex. To do so, we'll want to:
+#* Augment the color_*() family of functions with a mandatory "conf:
+#  BeartypeConf" parameter.
+#* Pass that parameter to *EVERY* call to one of those functions.
+#* Refactor those functions to respect that parameter. The ideal means of
+#  doing so would probably be define in the
+#  "beartype._util.text.utiltextansi" submodule:
+#  * A new "_BeartypeTheme" dataclass mapping from style names to format
+#    strings embedding the ANSI escape sequences styling those styles.
+#  * A new pair of private "_THEME_MONOCHROME" and "_THEME_PRISMATIC"
+#    instances of that dataclass. The values of the "_THEME_MONOCHROME"
+#    dictionary should all just be the default format string: e.g.,
+#    _THEME_MONOCHROME = _BeartypeTheme(
+#        format_error='{text}',
+#        ...
+#    )
+#
+#    _THEME_PRISMATIC = _BeartypeTheme(
+#        format_error=f'{_STYLE_BOLD}{_COLOUR_RED}{{text}}{_COLOUR_RESET}',
+#        ...
+#    )
+#  * A new "_THEME_DEFAULT" instance of that dataclass conditionally defined
+#    as either "_THEME_MONOCHROME" or "_THEME_PRISMATIC" depending on
+#    whether stdout is attached to a TTY or not. Alternately, to avoid
+#    performing that somewhat expensive logic at module scope (and thus on
+#    initial beartype importation), it might be preferable to instead define
+#    a new cached private getter resembling:
+#
+#    @callable_cached
+#    def _get_theme_default() -> _BeartypeTheme:
+#        return (
+#            _THEME_PRISMATIC
+#            if is_stdout_terminal() else
+#            _THEME_MONOCHROME
+#        )
+
 # ....................{ IMPORTS                            }....................
 from beartype.meta import URL_ISSUES
 from beartype.roar._roarexc import (
     _BeartypeCallHintPepRaiseDesynchronizationException,
     _BeartypeCallHintPepRaiseException,
 )
-from beartype.typing import (
-    Optional,
-)
+from beartype.typing import Optional
+from beartype._check.error._errorcause import ViolationCause
 from beartype._conf.confcls import (
     BEARTYPE_CONF_DEFAULT,
     BeartypeConf,
@@ -83,20 +123,19 @@ from beartype._data.hint.datahinttyping import (
     TypeException,
     TypeStack,
 )
-from beartype._check.error._errorcause import ViolationCause
-from beartype._check.error._util.errorutilcolor import (
+from beartype._util.text.utiltextansi import (
     color_hint,
-    color_repr,
-    strip_text_ansi_if_configured,
-)
-from beartype._check.error._util.errorutiltext import (
-    prefix_beartypeable_arg_value,
-    prefix_beartypeable_return_value,
+    strip_str_ansi,
 )
 from beartype._util.text.utiltextmunge import (
     suffix_str_unless_suffixed,
     uppercase_str_char_first,
 )
+from beartype._util.text.utiltextprefix import (
+    prefix_callable_return_value,
+    prefix_callable_arg_value,
+    prefix_pith_value,
+)
 from beartype._util.text.utiltextrepr import represent_object
 from collections.abc import Callable as CallableABC
 
@@ -151,7 +190,10 @@ def get_func_pith_violation(
     Raises
     ------
     All exceptions raised by the lower-level :func:`.get_hint_object_violation`
-    getter.
+    getter as well as:
+
+    _BeartypeCallHintPepRaiseException
+        If the parameter or return with the passed name is unannotated.
 
     See Also
     --------
@@ -197,8 +239,9 @@ def get_hint_object_violation(
 
     # Optional parameters.
     func: Optional[CallableABC] = None,
-    pith_name: Optional[str] = None,
     cls_stack: TypeStack = None,
+    exception_prefix: Optional[str] = None,
+    pith_name: Optional[str] = None,
     random_int: Optional[int] = None,
 ) -> Exception:
     '''
@@ -258,6 +301,24 @@ def get_hint_object_violation(
         * Else, :data:`None`.
 
         Defaults to :data:`None`.
+    cls_stack : TypeStack, optional
+        **Type stack** (i.e., either a tuple of the one or more
+        :func:`beartype.beartype`-decorated classes lexically containing the
+        class variable or method annotated by this hint *or* :data:`None`).
+        Defaults to :data:`None`.
+    exception_prefix : Optional[str]
+        Either:
+
+        * If the caller prefers specifying an explicit human-readable label
+          prefixing the representation of this object in the exception message,
+          that labal.
+        * Else, :data:`None`. In this case, this getter automatically
+          synthesizes this label from the other passed parameters that are
+          required to be non-:data:`None`. If any such parameter is
+          :data:`None`, an exception is raised. These parameters include:
+
+          * The passed ``func`` parameter, required to be non-:data:`None`.
+          * The passed ``pith_name`` parameter, required to be non-:data:`None`.
     pith_name : Optional[str]
         Either:
 
@@ -266,11 +327,6 @@ def get_hint_object_violation(
         * If this hint annotates the return of some callable, ``"return"``.
         * Else, :data:`None`.
 
-        Defaults to :data:`None`.
-    cls_stack : TypeStack, optional
-        **Type stack** (i.e., either a tuple of the one or more
-        :func:`beartype.beartype`-decorated classes lexically containing the
-        class variable or method annotated by this hint *or* :data:`None`).
         Defaults to :data:`None`.
     random_int: Optional[int], optional
         **Pseudo-random integer** (i.e., unsigned 32-bit integer
@@ -309,7 +365,8 @@ def get_hint_object_violation(
     BeartypeDecorHintPepException
         If the type hint annotating this object is *not* PEP-compliant.
     _BeartypeCallHintPepRaiseException
-        If the parameter or return value with the passed name is unannotated.
+        If all three of the ``exception_prefix``,``func``, and ``pith_name``
+        parameters are :data:`None`.
     _BeartypeCallHintPepRaiseDesynchronizationException
         If this pith actually satisfies this hint, implying either:
 
@@ -320,40 +377,69 @@ def get_hint_object_violation(
           false positive by erroneously misdetecting this pith as satisfying
           this type check when in fact this pith fails to do so.
     '''
-
-    # print('''get_func_pith_violation(
+    # print('''get_hint_object_violation(
     #     func={!r},
+    #     hint={!r},
     #     conf={!r},
     #     pith_name={!r},
     #     pith_value={!r}',
-    # )'''.format(func, conf, pith_name, pith_value))
+    # )'''.format(func, hint, conf, pith_name, pith_value))
 
     # ....................{ LOCALS                         }....................
     # Type of violation to be raised.
     exception_cls: TypeException = None  # type: ignore[assignment]
 
-    # Substring prefixing the message of the violation to be raised below.
-    exception_prefix: str = None  # type: ignore[assignment]
-
-    # If the passed object is neither a parameter or return of a decorated
-    # callable, this object was directly passed to either the
-    # beartype.door.is_bearable() or beartype.door.die_if_unbearable()
-    # functions. In either case, set the above local variables appropriately.
+    # If the caller passed *NO* parameter name, the passed object is neither a
+    # parameter nor return of a decorated callable. By elimination, this object
+    # *MUST* have been directly passed to the beartype.door.die_if_unbearable()
+    # type-checker. In this case...
     if pith_name is None:
+        # If the caller also passed *NO* exception prefix, raise an exception.
+        if exception_prefix is None:
+            raise _BeartypeCallHintPepRaiseException(
+                'get_hint_object_violation() passed neither '
+                '"exception_prefix" nor "pith_name" parameters.'
+            )
+        # Else, the caller passed an exception prefix.
+
+        # Default the exception class appropriately.
         exception_cls = conf.violation_door_type
-        exception_prefix = 'Object '
-    # If the name of this parameter is the magic string implying the passed
-    # object to be a return value, set the above local variables appropriately.
-    elif pith_name == ARG_NAME_RETURN:
-        exception_cls = conf.violation_return_type
-        exception_prefix = prefix_beartypeable_return_value(
-            func=func, return_value=obj)  # type: ignore[arg-type]
-    # Else, the passed object is a parameter. In this case, set the above local
-    # variables appropriately.
+
+        # Suffix this exception prefix with an additional noun for disambiguity.
+        exception_prefix = (
+            f'{exception_prefix}value '
+            f'{prefix_pith_value(pith=obj, is_color=conf.is_color)}'
+        )
+    # Else, the caller passed a parameter name. In this case...
     else:
-        exception_cls = conf.violation_param_type
-        exception_prefix = prefix_beartypeable_arg_value(
-            func=func, arg_name=pith_name, arg_value=obj)  # type: ignore[arg-type]
+        # If the caller also passed an exception prefix, raise an exception.
+        if exception_prefix is not None:
+            raise _BeartypeCallHintPepRaiseException(
+                'get_hint_object_violation() passed both '
+                '"exception_prefix" and "pith_name" parameters.'
+            )
+        # Else, the caller passed *NO* exception prefix.
+
+        # If the name of this parameter is the magic string implying the passed
+        # object to be a return value...
+        if pith_name == ARG_NAME_RETURN:
+            # Default these exception locals appropriately
+            exception_cls = conf.violation_return_type
+            exception_prefix = prefix_callable_return_value(
+                func=func,  # type: ignore[arg-type]
+                return_value=obj,
+                is_color=conf.is_color,
+            )
+        # Else, the passed object is a parameter. In this case...
+        else:
+            # Default these exception locals appropriately
+            exception_cls = conf.violation_param_type
+            exception_prefix = prefix_callable_arg_value(
+                func=func,  # type: ignore[arg-type]
+                arg_name=pith_name,
+                arg_value=obj,
+                is_color=conf.is_color,
+            )
 
     # Uppercase the first character of this violation prefix for readability.
     exception_prefix = uppercase_str_char_first(exception_prefix)
@@ -382,14 +468,16 @@ def get_hint_object_violation(
         pith_value_repr = represent_object(
             obj=obj, max_len=_CAUSE_TRIM_OBJECT_REPR_MAX_LEN)
         raise _BeartypeCallHintPepRaiseDesynchronizationException(
-            f'{exception_prefix}violates type hint {color_hint(repr(hint))}, '
+            f'{exception_prefix}violates type hint {repr(hint)}, '
             f'but violation factory get_hint_object_violation() '
             f'erroneously suggests this object satisfies this hint. '
             f'Please report this desynchronization failure to '
             f'the beartype issue tracker ({URL_ISSUES}) with '
             f'the accompanying exception traceback and '
             f'the representation of this object:\n'
-            f'{color_repr(pith_value_repr)}'
+            f'    {pith_value_repr}\n'
+            f'The bear groans in disappointment. If you feel similarly, '
+            f'know that you are not alone.'
         )
     # Else, this pith violates this hint as expected and as required for sanity.
 
@@ -415,15 +503,16 @@ def get_hint_object_violation(
     # Violation verbosity, localized for negligible efficiency. *vomits*
     violation_verbosity = conf.violation_verbosity
 
+    # Machine-readable representation of this hint embellished with colour.
+    hint_repr = f'{color_hint(text=repr(hint), is_color=conf.is_color)}'
+
     # Dictionary mapping from each possibly violation verbosity to a
     # corresponding substring prepending this exception message.
     VIOLATION_VERBOSITY_TO_PREFIX = {
         BeartypeViolationVerbosity.MINIMAL: (
-            f'{exception_prefix}was expected to be of type '
-            f'{color_hint(repr(hint))}'
-        ),
+            f'{exception_prefix}was expected to be of type {hint_repr}'),
         BeartypeViolationVerbosity.DEFAULT: (
-            f'{exception_prefix}violates type hint {color_hint(repr(hint))}'),
+            f'{exception_prefix}violates type hint {hint_repr}'),
     }
     VIOLATION_VERBOSITY_TO_PREFIX[BeartypeViolationVerbosity.MAXIMAL] = (  # <-- alias!
         VIOLATION_VERBOSITY_TO_PREFIX[BeartypeViolationVerbosity.DEFAULT])
@@ -463,11 +552,19 @@ def get_hint_object_violation(
         f'{VIOLATION_VERBOSITY_TO_SUFFIX[violation_verbosity]}'
     )
 
-    #FIXME: Unit test us up, please.
+    #FIXME: In theory, this should no longer be needed. Consider:
+    #* Refactoring all instances of "is_color=True" throughout this subpackage
+    #  to instead read "is_color=cause.conf.is_color".
+    #* Refactoring all calls to the represent_pith() function throughout this
+    #  subpackage to additionally pass a new optional
+    #  "is_color=cause.conf.is_color" parameter.
+    #* Refactoring this call away.
+    #* Validating with unit tests that violation messages contain *NO* ANSI when
+    #  configured such that "BeartypeConf(is_color=False)".
     # Strip all ANSI escape sequences from this message if requested by this
     # external user-defined configuration.
-    exception_message = strip_text_ansi_if_configured(
-        text=exception_message, conf=conf)
+    exception_message = strip_str_ansi(
+        text=exception_message, is_color=conf.is_color)
 
     # Exception of the desired class embedding this cause. By default, attempt
     # to pass @beartype-specific parameters to this exception subclass.
