@@ -13,12 +13,19 @@ This private submodule is *not* intended for importation by downstream callers.
 '''
 
 # ....................{ IMPORTS                            }....................
-from ast import AST
+import beartype #  <-- satisfy mypy [note to self: i can't stand you, mypy]
+from ast import (
+    AST,
+    AsyncFunctionDef,
+    ClassDef,
+    FunctionDef,
+)
 from beartype.typing import (
-    # TYPE_CHECKING,
+    AbstractSet,
     Any,
     Callable,
     Dict,
+    ForwardRef,
     Iterable,
     List,
     Literal,
@@ -30,13 +37,14 @@ from beartype.typing import (
     Union,
 )
 from beartype._cave._cavefast import (
-    # MethodBoundInstanceOrClassType,
+    MethodBoundInstanceOrClassType,
     MethodDecoratorClassType,
     MethodDecoratorPropertyType,
     MethodDecoratorStaticType,
 )
 from beartype._data.hint.pep.sign.datapepsigncls import HintSign
 from beartype._data.func.datafuncarg import ARG_VALUE_UNPASSED
+from collections.abc import Callable as CallableABC
 from importlib.abc import PathEntryFinder
 from pathlib import Path
 from types import (
@@ -45,8 +53,68 @@ from types import (
     GeneratorType,
 )
 
+# ....................{ TYPEVARS                           }....................
+S = TypeVar('S')
+'''
+**Unbound type variable** (i.e., matching *any* arbitrary type) locally bound to
+different types than the :data:`.T` type variable.
+'''
+
+
+T = TypeVar('T')
+'''
+**Unbound type variable** (i.e., matching *any* arbitrary type) locally bound to
+different types than the :data:`.S` type variable.
+'''
+
+
+CallableT = TypeVar('CallableT', bound=CallableABC)
+'''
+**Callable type variable** (i.e., bound to match *only* callables).
+'''
+
+
+NodeT = TypeVar('NodeT', bound=AST)
+'''
+**Node type variable** (i.e., type variable constrained to match *only* abstract
+syntax tree (AST) nodes).
+'''
+
 # ....................{ AST                                }....................
-ListNodes = List[AST]
+NodeCallable = Union[FunctionDef, AsyncFunctionDef]
+'''
+PEP-compliant type hint matching a **callable node** (i.e., abstract syntax tree
+(AST) node encapsulating the definition of a pure-Python function or method that
+is either synchronous or asynchronous).
+'''
+
+
+NodeDecoratable = Union[NodeCallable, ClassDef]
+'''
+PEP-compliant type hint matching a **decoratable node** (i.e., abstract syntax
+tree (AST) node encapsulating the definition of a pure-Python object supporting
+decoration by one or more ``"@"``-prefixed decorations, including both
+pure-Python classes *and* callables).
+'''
+
+
+NodeVisitResult = Optional[Union[AST, List[AST]]]
+'''
+PEP-compliant type hint matching a **node visitation result** (i.e., object
+returned by any visitor method of an :class:`ast.NodeVisitor` subclass).
+
+Specifically, this hint matches either:
+
+* A single node, in which case a visitor method has effectively preserved the
+  currently visited node passed to that method in the AST.
+* A list of zero or more nodes, in which case a visitor method has replaced the
+  currently visited node passed to that method with those nodes in the AST.
+* :data:`None`, in which case a visitor method has effectively destroyed the
+  currently visited node passed to that method from the AST.
+'''
+
+
+NodesList = List[AST]
 '''
 PEP-compliant type hint matching an **abstract syntax tree (AST) node list**
 (i.e., list of zero or more AST nodes).
@@ -141,15 +209,6 @@ checkers (e.g., :mod:`mypy`) and type-aware IDEs (e.g., VSCode) that the
 # ....................{ CALLABLE                           }....................
 # Callable-specific type hints *NOT* required by subsequent type hints below.
 
-BeartypeDecorator = Callable[[BeartypeableT], BeartypeableT]
-'''
-PEP-compliant type hint matching a **beartype-like decorator** (i.e., callable
-presumably decorating a passed object by the :func:`beartype.beartype` decorator
-under a possibly non-default beartype configuration and returning the resulting
-decorated object).
-'''
-
-
 CallableRaiser = Callable[[object], None]
 '''
 PEP-compliant type hint matching a **raiser callable** (i.e., arbitrary callable
@@ -190,6 +249,27 @@ Specifically, this hint matches:
 * Pure-Python callable stack frames.
 '''
 
+
+MethodDescriptorNondata = Union[
+    # A C-based unbound class method descriptor (i.e., a pure-Python unbound
+    # function decorated by the builtin @classmethod decorator) *OR*...
+    MethodDecoratorClassType,
+
+    # A C-based unbound static method descriptor (i.e., a pure-Python
+    # unbound function decorated by the builtin @staticmethod decorator).
+    MethodDecoratorStaticType,
+
+    # A C-based bound method descriptor (i.e., a pure-Python unbound
+    # function bound to an object instance on Python's instantiation of that
+    # object) *OR*...
+    MethodBoundInstanceOrClassType,
+]
+'''
+PEP-compliant type hint matching any **builtin method non-data descriptor**
+(i.e., C-based descriptor builtin to Python defining only the ``__get__()``
+dunder method, encapsulating read-only access to some kind of method).
+'''
+
 # ....................{ CALLABLE ~ args                    }....................
 CallableMethodGetitemArg = Union[int, slice]
 '''
@@ -310,6 +390,12 @@ Equivalently, this hint matches all objects passable as the second parameters
 to the :func:`isinstance` and :func:`issubclass` builtins.
 '''
 
+
+SetOrTupleTypes = Union[AbstractSet[type], TupleTypes]
+'''
+PEP-compliant type hint matching a set *or* tuple of zero or more classes.
+'''
+
 # ....................{ TUPLE ~ stack                      }....................
 TypeStack = Optional[Tuple[type, ...]]
 '''
@@ -382,6 +468,25 @@ number of classes lexically nesting the currently decorated class as input
 metadata, as trivially provided by the length of this tuple.
 '''
 
+# ....................{ MODULE ~ beartype                  }....................
+BeartypeForwardRef = Type[
+    'beartype._check.forward.reference.fwdrefabc.BeartypeForwardRefABC']  # pyright: ignore
+'''
+PEP-compliant type hint matching a **forward reference proxy** (i.e., concrete
+subclass of the abstract
+:class:`beartype._check.forward.reference.fwdrefabc.BeartypeForwardRefABC`
+superclass).
+'''
+
+
+BeartypeForwardRefArgs = Tuple[Optional[str], str, TupleTypes]
+'''
+PEP-compliant type hint matching a **forward reference proxy argument list**
+(i.e., tuple of all parameters passed to each call of the low-level private
+:func:`beartype._check.forward.reference.fwdrefmake._make_forwardref_subtype`
+factory function, in the same order as positionally accepted by that function).
+'''
+
 # ....................{ MODULE ~ importlib                 }....................
 # Type hints specific to the standard "importlib" package.
 
@@ -426,6 +531,20 @@ Pep484TowerFloat = Union[float, int]
 (i.e., both floating-point numbers and integers).
 '''
 
+# ....................{ PEP (484|585)                      }....................
+# Type hints required to fully comply with both PEP 484 *AND* 585.
+
+Pep484585ForwardRef = Union[str, ForwardRef]
+'''
+Union of all :pep:`484`- or :pep:`585`-compliant **forward reference types**
+(i.e., classes of all forward reference objects).
+
+See Also
+--------
+:data:`HINT_PEP484585_FORWARDREF_TYPES`
+    Further details.
+'''
+
 # ....................{ TYPE                               }....................
 TypeException = Type[Exception]
 '''
