@@ -73,6 +73,7 @@ from beartype._data.hint.pep.sign.datapepsigns import (
     HintSignParamSpec,
     # HintSignParamSpecArgs,
     HintSignPep557DataclassInitVar,
+    HintSignTypeAlias,
     HintSignPep695TypeAlias,
     # HintSignProtocol,
     HintSignReversible,
@@ -613,6 +614,7 @@ def _init() -> None:
             # case, silently continue to the next sign.
             if not hint_sign_name.startswith('HintSign'):
                 continue
+            # Else, this name is that of a sign.
 
             # Sign with this name.
             hint_sign = getattr(datapepsigns, hint_sign_name)
@@ -695,6 +697,7 @@ def _init() -> None:
     # Uncomment as needed to display the contents of these objects.
 
     # from pprint import pformat
+    # print(f'HINTS_PEP484_REPR_PREFIX_DEPRECATED: {pformat(HINTS_PEP484_REPR_PREFIX_DEPRECATED)}')
     # print(f'HINT_REPR_PREFIX_ARGS_0_OR_MORE_TO_SIGN: {pformat(HINT_REPR_PREFIX_ARGS_0_OR_MORE_TO_SIGN)}')
     # print(f'HINT_REPR_PREFIX_ARGS_1_OR_MORE_TO_SIGN: {pformat(HINT_REPR_PREFIX_ARGS_1_OR_MORE_TO_SIGN)}')
     # print(f'HINT_TYPE_NAME_TO_SIGN: {pformat(HINT_TYPE_NAME_TO_SIGN)}')
