@@ -32,19 +32,27 @@ from beartype._data.hint.datahinttyping import (
     BeartypeableT,
 )
 from beartype._decor.wrap.wrapmain import generate_code
-from beartype._util.cache.pool.utilcachepoolobjecttyped import (
-    release_object_typed)
-from beartype._util.func.mod.utilbeartypefunc import (
+from beartype._util.api.utilapibeartype import (
     is_func_unbeartypeable,
     set_func_beartyped,
 )
-from beartype._util.func.mod.utilfuncmodtest import (
-    is_func_contextlib_contextmanager,
-    is_func_functools_lru_cache,
-)
+from beartype._util.api.utilapicontextlib import (
+    is_func_contextlib_contextmanager)
+from beartype._util.api.utilapifunctools import is_func_functools_lru_cache
+from beartype._util.cache.pool.utilcachepoolobjecttyped import (
+    release_object_typed)
+from beartype._util.func.utilfuncget import get_func_boundmethod_self
 from beartype._util.func.utilfuncmake import make_func
-from beartype._util.func.utilfunctest import is_func_python
-from beartype._util.func.utilfuncwrap import unwrap_func_once
+from beartype._util.func.utilfunctest import (
+    is_func_boundmethod,
+    is_func_python,
+)
+from beartype._util.func.utilfuncwrap import (
+    unwrap_func_once,
+    unwrap_func_boundmethod_once,
+    unwrap_func_classmethod_once,
+    unwrap_func_staticmethod_once,
+)
 from beartype._util.py.utilpyversion import IS_PYTHON_3_8
 from contextlib import contextmanager
 from functools import lru_cache
@@ -65,7 +73,7 @@ def beartype_nontype(obj: BeartypeableT, **kwargs) -> BeartypeableT:
     defined by this submodule (e.g., :func:`.beartype_func`).
 
     Returns
-    ----------
+    -------
     BeartypeableT
         New pure-Python callable wrapping this beartypeable with type-checking.
     '''
@@ -86,7 +94,6 @@ def beartype_nontype(obj: BeartypeableT, **kwargs) -> BeartypeableT:
     # resolve to warrant doing so. To do so, this conditional branch effectively
     # reorders @beartype to be the first decorator decorating the pure-Python
     # function underlying this method descriptor: e.g.,
-    #
     #     # This branch detects and reorders this edge case...
     #     class MuhClass(object):
     #         @beartype
@@ -123,7 +130,7 @@ def beartype_nontype(obj: BeartypeableT, **kwargs) -> BeartypeableT:
     # runtime type-checking into this pure-Python callable by replacing the
     # bound method descriptor of the type of this object implementing the
     # __call__() dunder method with a comparable descriptor calling a
-    # @beartype-generated runtime type-checking wrapper function.
+    # @beartype-generated runtime type-checking wrapper function. Go with it.
     elif not is_func_python(obj):
         return beartype_pseudofunc(obj, **kwargs)  # type: ignore[return-value]
     # Else, this object is a pure-Python function.
@@ -144,7 +151,6 @@ def beartype_nontype(obj: BeartypeableT, **kwargs) -> BeartypeableT:
     # type-checkers dynamically generated by @beartype for those managers would
     # erroneously raise type-checking violations after calling those managers
     # and detecting the apparent type violation: e.g.,
-    #
     #     >>> from beartype.typing import Iterator
     #     >>> from contextlib import contextmanager
     #     >>> @contextmanager
@@ -155,7 +161,6 @@ def beartype_nontype(obj: BeartypeableT, **kwargs) -> BeartypeableT:
     # This conditional branch effectively reorders @beartype to be the first
     # decorator decorating the callable underlying this context manager,
     # preserving consistency between return types *AND* return type hints: e.g.,
-    #
     #     from beartype.typing import Iterator
     #     from contextlib import contextmanager
     #
@@ -200,7 +205,7 @@ def beartype_func(
     :meth:`beartype._check.checkcall.BeartypeCall.reinit` method.
 
     Returns
-    ----------
+    -------
     BeartypeableT
         New pure-Python callable wrapping this callable with type-checking.
     '''
@@ -316,7 +321,7 @@ def beartype_func_contextlib_contextmanager(
     decorator on the pure-Python function encapsulated in this descriptor.
 
     Returns
-    ----------
+    -------
     BeartypeableT
         New pure-Python callable wrapping this context manager with
         type-checking.
@@ -354,12 +359,12 @@ def beartype_descriptor_decorator_builtin(
     decorator on the pure-Python function encapsulated in this descriptor.
 
     Returns
-    ----------
+    -------
     BeartypeableT
         New pure-Python callable wrapping this descriptor with type-checking.
 
     Raises
-    ----------
+    ------
     BeartypeDecorWrappeeException
         If this descriptor is neither a class, property, or static method
         descriptor.
@@ -416,8 +421,45 @@ def beartype_descriptor_decorator_builtin(
     #
     # If this descriptor is a class method...
     elif descriptor_type is MethodDecoratorClassType:
-        # Pure-Python unbound function type-checking this class method.
+        # Possibly C-based callable wrappee object decorated by this descriptor.
         #
+        # Note that this wrappee is typically but *NOT* necessarily a
+        # pure-Python unbound function. This descriptor explicitly permits the
+        # decorated object to be a callable C-based type (i.e., defining the
+        # __call__() dunder method), which numerous standard and third-party
+        # pure-Python classes then leverage to augment those classes into
+        # subscriptable type hint factories via a simple one-liner: e.g.,
+        #     from abc import ABCMeta
+        #     from beartype import beartype
+        #     from types import GenericAlias
+        #
+        #     @beartype
+        #     class MuhTypeHintFactory(metaclass=ABCMeta):
+        #         # This exact one liner appears verbatim throughout the
+        #         # standard library (as well as third-party packages).
+        #         __class_getitem__ = classmethod(GenericAlias)
+        #
+        # Ergo, the name "__func__" of this dunder attribute is disingenuous.
+        # This descriptor does *NOT* merely decorate functions; this descriptor
+        # permissively decorates all callable objects.
+        descriptor_wrappee = unwrap_func_classmethod_once(descriptor)  # type: ignore[arg-type]
+
+        # If this wrappee is *NOT* a pure-Python unbound function, this wrappee
+        # is C-based and/or a type. In either case, avoid type-checking this
+        # wrappee by silently preserving this descriptor as is. Why? If this
+        # wrappee is:
+        # * C-based, this wrappee *CANNOT* be decorated with type-checking.
+        # * A type, this wrappee *COULD* be effectively decorated with
+        #   type-checking by decorating its __call__() dunder method. However,
+        #   this type may *NOT* have been intended to be decorated by @beartype.
+        #   Indeed, this type may *NOT* even reside within the same package.
+        #   That the current class references this type is an insufficient
+        #   reason to transitively decorate external types without user consent.
+        if not is_func_python(descriptor_wrappee):
+            return descriptor
+        # Else, this wrappee is a pure-Python unbound function.
+
+        # Pure-Python unbound function type-checking this class method.
         # Note that:
         # * Python 3.8, 3.9, and 3.10 explicitly permit the @classmethod
         #   decorator to be chained into the @property decorator: e.g.,
@@ -454,7 +496,7 @@ def beartype_descriptor_decorator_builtin(
         #   * The low-level beartype_func() decorator (which requires the passed
         #     object to be callable, which the descriptor created and returned
         #     by the @property decorator is *NOT*).
-        func_checked = beartype_nontype(descriptor.__func__,  **kwargs)  # type: ignore[union-attr]
+        func_checked = beartype_nontype(descriptor_wrappee,  **kwargs)
 
         # Return a new class method descriptor decorating the pure-Python
         # unbound function wrapped by this descriptor with type-checking,
@@ -464,8 +506,11 @@ def beartype_descriptor_decorator_builtin(
     #
     # If this descriptor is a static method...
     elif descriptor_type is MethodDecoratorStaticType:
+        # Possibly C-based callable wrappee object decorated by this descriptor.
+        descriptor_wrappee = unwrap_func_staticmethod_once(descriptor)  # type: ignore[arg-type]
+
         # Pure-Python unbound function type-checking this static method.
-        func_checked = beartype_func(descriptor.__func__, **kwargs) # type: ignore[union-attr]
+        func_checked = beartype_func(descriptor_wrappee, **kwargs) # type: ignore[union-attr]
 
         # Return a new static method descriptor decorating the pure-Python
         # unbound function wrapped by this descriptor with type-checking,
@@ -481,7 +526,7 @@ def beartype_descriptor_decorator_builtin(
     )
 
 # ....................{ PRIVATE ~ decorators               }....................
-def _beartype_descriptor_method_bound(
+def _beartype_descriptor_boundmethod(
     descriptor: BeartypeableT, **kwargs) -> BeartypeableT:
     '''
     Decorate the passed **builtin bound method object** (i.e., C-based bound
@@ -499,15 +544,18 @@ def _beartype_descriptor_method_bound(
     decorator on the pure-Python function encapsulated in this descriptor.
 
     Returns
-    ----------
+    -------
     BeartypeableT
         New pure-Python callable wrapping this descriptor with type-checking.
     '''
-    assert isinstance(descriptor, MethodBoundInstanceOrClassType), (
+    assert is_func_boundmethod(descriptor), (
         f'{repr(descriptor)} not builtin bound method descriptor.')
 
-    # Pure-Python unbound function encapsulated by this descriptor.
-    descriptor_func_old = descriptor.__func__
+    # Possibly C-based callable wrappee object encapsulated by this descriptor.
+    descriptor_wrappee = unwrap_func_boundmethod_once(descriptor)
+
+    # Instance object to which this descriptor was bound at instantiation time.
+    descriptor_self = get_func_boundmethod_self(descriptor)
 
     # Pure-Python unbound function decorating the similarly pure-Python unbound
     # function encapsulated by this descriptor with type-checking.
@@ -520,7 +568,7 @@ def _beartype_descriptor_method_bound(
     #   descriptor (created below) encapsulating this wrapper function. Bad!
     #   Thankfully, only one such attribute exists as of this time: "__doc__".
     #   We propagate this attribute manually below.
-    descriptor_func_new = beartype_func(func=descriptor_func_old, **kwargs)  # pyright: ignore
+    func_checked = beartype_func(func=descriptor_wrappee, **kwargs)  # pyright: ignore
 
     # New instance method descriptor rebinding this function to the instance of
     # the class bound to the prior descriptor.
@@ -538,7 +586,7 @@ def _beartype_descriptor_method_bound(
     #   That said, there exist *NO* benefits to doing so. Indeed, doing so only
     #   reduces the legibility and maintainability of this operation.
     descriptor_new = MethodBoundInstanceOrClassType(
-        descriptor_func_new, descriptor.__self__)  # type: ignore[return-value]
+        func_checked, descriptor_self)  # type: ignore[return-value]
 
     #FIXME: Actually, Python doesn't appear to support this at the moment.
     #Attempting to do so raises this exception:
@@ -581,7 +629,7 @@ def beartype_pseudofunc(pseudofunc: BeartypeableT, **kwargs) -> BeartypeableT:
     decorator on the pure-Python function encapsulated in this descriptor.
 
     Returns
-    ----------
+    -------
     BeartypeableT
         The object monkey-patched by :func:`beartype.beartype`.
     '''
@@ -606,7 +654,7 @@ def beartype_pseudofunc(pseudofunc: BeartypeableT, **kwargs) -> BeartypeableT:
             f'(i.e., callable object defining __call__() dunder method).'
         )
     # Else, this object is a pseudo-callable.
-
+    #
     # If this method is *NOT* pure-Python, this method is C-based. In this
     # case...
     #
@@ -615,7 +663,7 @@ def beartype_pseudofunc(pseudofunc: BeartypeableT, **kwargs) -> BeartypeableT:
     # does *NOT* apply to C-based pseudo-callables; indeed, there exists *NO*
     # general-purpose means of safely monkey-patching the latter. Instead,
     # specific instances of the latter *MUST* be manually detected and handled.
-    if not is_func_python(pseudofunc_call_method):
+    elif not is_func_python(pseudofunc_call_method):
         # If this is a C-based @functools.lru_cache-memoized callable (i.e.,
         # low-level C-based callable object both created and returned by the
         # standard @functools.lru_cache decorator), @beartype was listed above
@@ -640,8 +688,8 @@ def beartype_pseudofunc(pseudofunc: BeartypeableT, **kwargs) -> BeartypeableT:
         #     def muh_lru_cache() -> None: pass
         if is_func_functools_lru_cache(pseudofunc):
             # Return a new callable decorating that callable with type-checking.
-            return beartype_pseudofunc_functools_lru_cache(  # type: ignore[return-value]
-                pseudofunc=pseudofunc, **kwargs)
+            return beartype_pseudofunc_functools_lru_cache(  # type: ignore
+                pseudofunc=pseudofunc, **kwargs)  # pyright: ignore
         # Else, this is *NOT* a C-based @functools.lru_cache-memoized callable.
 
     # Replace the existing bound method descriptor to this __call__() dunder
@@ -664,7 +712,7 @@ def beartype_pseudofunc(pseudofunc: BeartypeableT, **kwargs) -> BeartypeableT:
     #   harmful, @beartype prefers the former. See also official documentation
     #   on the subject:
     #       https://docs.python.org/3/reference/datamodel.html#special-method-names
-    pseudofunc.__class__.__call__ = _beartype_descriptor_method_bound(  # type: ignore[assignment,method-assign]
+    pseudofunc.__class__.__call__ = _beartype_descriptor_boundmethod(  # type: ignore[assignment,method-assign]
         descriptor=pseudofunc_call_method, **kwargs)
 
     # Return this monkey-patched object.
@@ -689,7 +737,7 @@ def beartype_pseudofunc_functools_lru_cache(
     decorator on the pure-Python function encapsulated in this descriptor.
 
     Returns
-    ----------
+    -------
     BeartypeableT
         New pseudo-callable monkey-patched by :func:`beartype.beartype`.
     '''
