@@ -65,12 +65,12 @@ def get_func_globals(
         to :class:`._BeartypeUtilCallableScopeException`.
 
     Returns
-    ----------
+    -------
     Dict[str, Any]
         Global scope for this callable.
 
     Raises
-    ----------
+    ------
     exception_cls
         If this callable is a wrapper wrapping a C-based rather than
         pure-Python wrappee callable.
@@ -146,7 +146,7 @@ def get_func_locals(
     has yet to be declared and thus added to the call stack.
 
     Caveats
-    ----------
+    -------
     **This high-level getter requires the private low-level**
     :func:`sys._getframe` **getter.** If that getter is undefined, this getter
     unconditionally treats the passed callable as module-scoped by returning the
@@ -187,12 +187,12 @@ def get_func_locals(
         to :class:`._BeartypeUtilCallableScopeException`.
 
     Returns
-    ----------
+    -------
     LexicalScope
         Local scope for this callable.
 
     Raises
-    ----------
+    ------
     exception_cls
         If the next non-ignored frame following the last ignored frame is *not*
         the parent callable or module directly declaring the passed callable.
@@ -215,10 +215,8 @@ def get_func_locals(
 
     # ..................{ IMPORTS                            }..................
     # Avoid circular import dependencies.
-    from beartype._util.func.utilfunccodeobj import (
-        FUNC_CODEOBJ_NAME_MODULE,
-        get_func_codeobj_or_none,
-    )
+    from beartype._data.func.datafunccodeobj import FUNC_CODEOBJ_NAME_MODULE
+    from beartype._util.func.utilfunccodeobj import get_func_codeobj_or_none
     from beartype._util.func.utilfuncframe import iter_frames
     from beartype._util.func.utilfunctest import is_func_nested
 
@@ -533,13 +531,13 @@ def add_func_scope_attr(
         exception message. Defaults to the empty string.
 
     Returns
-    ----------
+    -------
     str
         Name of the passed object in this scope generated by this function.
 
     Raises
-    ----------
-    :exc:`._BeartypeUtilCallableScopeException`
+    ------
+    _BeartypeUtilCallableScopeException
         If an attribute with the same name as that internally generated by
         this adder but having a different value already exists in this scope.
         This adder uniquifies names by object identifier and should thus
@@ -608,7 +606,7 @@ Arbitrary substring prefixing names dynamically synthesized by the
 the integers returned by the :func:`id` builtin) are positive.
 
 See Also
-----------
+--------
 :data:`._ATTR_NAME_PREFIX_ID_NEGATIVE`
     Further details.
 '''
