@@ -48,6 +48,7 @@ from beartype.roar._roarexc import (
     BeartypeCaveNoneTypeOrMutabilityException as BeartypeCaveNoneTypeOrMutabilityException,
     BeartypeClawException as BeartypeClawException,
     BeartypeClawHookException as BeartypeClawHookException,
+    BeartypeClawHookUnpackagedException as BeartypeClawHookUnpackagedException,
     BeartypeClawImportException as BeartypeClawImportException,
     BeartypeClawImportAstException as BeartypeClawImportAstException,
     BeartypeClawImportConfException as BeartypeClawImportConfException,
@@ -104,6 +105,7 @@ from beartype.roar._roarexc import (
     BeartypeCallHintViolation as BeartypeCallHintViolation,
     BeartypeCallHintParamViolation as BeartypeCallHintParamViolation,
     BeartypeCallHintReturnViolation as BeartypeCallHintReturnViolation,
+    BeartypeDecorHintParamDefaultViolation as BeartypeDecorHintParamDefaultViolation,
     BeartypeDoorHintViolation as BeartypeDoorHintViolation,
 )
 
@@ -115,10 +117,11 @@ from beartype.roar._roarwarn import (
     BeartypeConfWarning as BeartypeConfWarning,
     BeartypeConfShellVarWarning as BeartypeConfShellVarWarning,
     BeartypeDecorHintWarning as BeartypeDecorHintWarning,
-    # BeartypeDecorHintForwardRefWarning as BeartypeDecorHintForwardRefWarning,
+    BeartypeDecorHintParamDefaultForwardRefWarning as BeartypeDecorHintParamDefaultForwardRefWarning,
     BeartypeDecorHintPepWarning as BeartypeDecorHintPepWarning,
     BeartypeDecorHintPepDeprecationWarning as BeartypeDecorHintPepDeprecationWarning,
     BeartypeDecorHintPep585DeprecationWarning as BeartypeDecorHintPep585DeprecationWarning,
+    BeartypeDecorHintPep613DeprecationWarning as BeartypeDecorHintPep613DeprecationWarning,
     BeartypeDecorHintNonpepWarning as BeartypeDecorHintNonpepWarning,
     BeartypeDecorHintNonpepNumpyWarning as BeartypeDecorHintNonpepNumpyWarning,
     BeartypeModuleWarning as BeartypeModuleWarning,
