@@ -19,10 +19,12 @@ from beartype.typing import (
     Iterator,
 )
 from beartype._util.func.utilfuncmake import make_func
+from collections import defaultdict
 from contextlib import contextmanager
 from enum import Enum
 from functools import (
     lru_cache,
+    partial,
     wraps,
 )
 from sys import exc_info
@@ -201,16 +203,7 @@ class NonIssubclassableClass(object, metaclass=NonIssubclassableMetaclass):
     pass
 
 # ....................{ CLASSES ~ with : module name       }....................
-class ClassWithModuleNameNone(object):
-    '''
-    Arbitrary pure-Python class with a **missing module name** (i.e., whose
-    ``__module__`` dunder attribute is :data:`None`).
-    '''
-
-    pass
-
-
-class ClassWithModuleNameNonexistent(object):
+class ClassModuleNameFake(object):
     '''
     Arbitrary pure-Python class with a **non-existent module name** (i.e., whose
     ``__module__`` dunder attribute refers to a file that is guaranteed to *not*
@@ -220,10 +213,18 @@ class ClassWithModuleNameNonexistent(object):
     pass
 
 
+class ClassModuleNameNone(object):
+    '''
+    Arbitrary pure-Python class with a **missing module name** (i.e., whose
+    ``__module__`` dunder attribute is :data:`None`).
+    '''
+
+    pass
+
+
 # Monkey-patch the above classes with "bad" module names.
-ClassWithModuleNameNone.__module__ = None
-ClassWithModuleNameNonexistent.__module__ = (
-    'If_I.were.a_dead_leaf.thou_mightest.bear')
+ClassModuleNameFake.__module__ = 'If_I.were.a_dead_leaf.thou_mightest.bear'
+ClassModuleNameNone.__module__ = None
 
 # ....................{ CALLABLES ~ async : factory        }....................
 # Note that we intentionally avoid declaring a factory function for deprecated
@@ -288,6 +289,12 @@ def function():
     pass
 
 
+function_lambda = lambda: 'The day was fair and sunny: sea and sky'
+'''
+Arbitrary pure-Python lambda function physically declared by this submodule.
+'''
+
+
 function_in_memory = make_func(
     func_name='function_in_memory',
     func_code='''
@@ -448,7 +455,7 @@ sync_generator = sync_generator_factory()
 Arbitrary pure-Python synchronous generator.
 '''
 
-# ....................{ CALLABLES ~ sync : module          }....................
+# ....................{ CALLABLES ~ sync : mod : contextlib}....................
 @contextmanager
 def context_manager_factory(obj: object) -> Iterator[object]:
     '''
@@ -460,15 +467,105 @@ def context_manager_factory(obj: object) -> Iterator[object]:
 
     yield obj
 
-
+# ....................{ CALLABLES ~ sync : mod : functools }....................
 @lru_cache
-def lru_cache_func(n: int) -> int:
+def function_lru_cached(n: int) -> int:
     '''
     Arbitrary :func:`functools.lru_cache`-memoized function.
     '''
 
     return n + 1
 
+
+def function_partialized(
+    and_one_majestic_river: str,
+    that_mighty_shadow_loves: str,
+) -> str:
+    '''
+    Arbitrary pure-Python function to be wrapped by the :class:`.partial`
+    factory as the :data:`.function_partial` object, accepting both positional
+    and keyword parameters to exercise all possible edge cases.
+    '''
+
+    return and_one_majestic_river + that_mighty_shadow_loves
+
+
+FUNCTION_PARTIALIZED_ARG_VALUE = (
+    'The breath and blood of distant lands, for ever')
+'''
+Arbitrary value passed as the first and only positional parameter to the
+:func:`function_partialized` function by the :data:`.function_partial` object.
+'''
+
+
+FUNCTION_PARTIALIZED_KWARG_NAME = 'that_mighty_shadow_loves'
+'''
+Name of the first and only keyword parameter passed to the
+:func:`function_partialized` function by the :data:`.function_partial` object.
+'''
+
+
+FUNCTION_PARTIALIZED_KWARG_VALUE = 'The slimy caverns of the populous deep.'
+'''
+Arbitrary value passed as the first and only keyword parameter to the
+:func:`function_partialized` function by the :data:`.function_partial` object.
+'''
+
+
+builtin_partial = partial(divmod, 2)
+'''
+Arbitrary instance of the :class:`.partial` factory wrapping the C-based
+:func:`divmod` builtin.
+'''
+
+
+function_partial = partial(
+    function_partialized,
+    FUNCTION_PARTIALIZED_ARG_VALUE,
+    that_mighty_shadow_loves=FUNCTION_PARTIALIZED_KWARG_VALUE,
+)
+'''
+Arbitrary instance of the :class:`.partial` factory wrapping the pure-Python
+:func:`function_partialized` function.
+'''
+
+
+function_partial_bad = partial(
+    function_partialized,
+    FUNCTION_PARTIALIZED_ARG_VALUE,
+    that_mighty_shadow_loves=FUNCTION_PARTIALIZED_KWARG_VALUE,
+    the_day_was_fair_and_sunny='sea and sky',
+)
+'''
+Arbitrary instance of the :class:`.partial` factory wrapping the pure-Python
+:func:`function_partialized` function in an invalid manner by passing more
+parameters than that function actually accepts.
+'''
+
+# ....................{ CALLABLES ~ sync : module          }....................
+def function_module_name_fake() -> None:
+    '''
+    Arbitrary pure-Python class with a **non-existent module name** (i.e., whose
+    ``__module__`` dunder attribute refers to a file that is guaranteed to *not*
+    exist on the local filesystem).
+    '''
+
+    pass
+
+
+def function_module_name_none() -> None:
+    '''
+    Arbitrary pure-Python function with a **missing module name** (i.e., whose
+    ``__module__`` dunder attribute is :data:`None`).
+    '''
+
+    pass
+
+
+# Monkey-patch the above callables with "bad" module names.
+function_module_name_fake.__module__ = 'He_had.a_mask.like_Castlereagh'
+function_module_name_none.__module__ = None
+
 # ....................{ CONSTANTS                          }....................
 CALLABLE_CODE_OBJECT = function.__code__
 '''
@@ -494,6 +591,32 @@ MODULE_FILENAME = __file__
 Absolute filename of the current submodule, declared purely for convenience.
 '''
 
+# ....................{ DICTS                              }....................
+def _default_dict_str_factory() -> str:
+    '''
+    Arbitrary factory function returning arbitrary strings.
+    '''
+
+    return 'His steps to the sea-shore. A swan was there,'
+
+
+default_dict_int_to_str = defaultdict(_default_dict_str_factory)
+'''
+Non-empty default dictionary mapping integers to strings, initialized with an
+arbitrary factory function returning arbitrary strings.
+'''
+default_dict_int_to_str[0] = 'Beside a sluggish stream among the reeds.'
+default_dict_int_to_str[1] # == 'His steps to the sea-shore. A swan was there,'
+
+
+default_dict_str_to_str = defaultdict(_default_dict_str_factory)
+'''
+Non-empty default dictionary mapping strings to strings, initialized with an
+arbitrary factory function returning arbitrary strings.
+'''
+default_dict_str_to_str['His eyes pursued its flight.'] = (
+    'Thou hast a home,')
+
 # ....................{ SETS ~ callable                    }....................
 CALLABLES_PYTHON = frozenset((
     function,
