@@ -163,8 +163,8 @@ exclude_patterns = [
 rst_prolog = '''
 .. tip::
 
-   `Feed the bear! The bear is rifling around in the refuse pile outside.
-   <GitHub Sponsors_>` You feel sadness, then trepidation.
+   `Feed the bear! The bear is rooting around in your refuse pile <GitHub
+   Sponsors_>`__. You feel sadness.
 '''
    # `Feed the bear <GitHub Sponsors_>`__! `Animals wearing jewelry
    # <beadspace9_>`__! *What is even going on with this banner!?*
